From 7ceaa78b4ad5d7f25cd44351e4e52e75429a1341 Mon Sep 17 00:00:00 2001
From: Gesner Passos <gesner.passos@stfc.ac.uk>
Date: Tue, 30 Oct 2012 11:45:59 +0000
Subject: [PATCH] Solve extra warnings that was confusing the user

Q1D2: correct the warning message to have WorkspaceIndex.

SANSRunWindow:
  * warning user that we will ignore the FLOOD file option when
the detector is the FRONT/HAB detector. A new ticket will be opened to deal
with this properly.
  * Skip reloading the user file for every single reduction that caused
extra warnings to appear, confusing the user.
  * Accept DET/MERGE option to be passed as well as DET/MERGED.

ISISCommandInterface-> temporaly clear the FloodFile when reducting the FRONT/HAB detector.

re #5844
---
 Code/Mantid/Framework/Algorithms/src/Q1D2.cpp          |  3 ++-
 .../MantidQt/CustomInterfaces/src/SANSRunWindow.cpp    | 10 ++++++----
 Code/Mantid/scripts/SANS/ISISCommandInterface.py       |  1 +
 3 files changed, 9 insertions(+), 5 deletions(-)

diff --git a/Code/Mantid/Framework/Algorithms/src/Q1D2.cpp b/Code/Mantid/Framework/Algorithms/src/Q1D2.cpp
index a6f36f228a9..b241a0cfab2 100644
--- a/Code/Mantid/Framework/Algorithms/src/Q1D2.cpp
+++ b/Code/Mantid/Framework/Algorithms/src/Q1D2.cpp
@@ -12,6 +12,7 @@
 #include "MantidDataObjects/Histogram1D.h"
 #include "MantidAlgorithms/Qhelper.h"
 #include "MantidKernel/BoundedValidator.h"
+#include "MantidAPI/ISpectrum.h"
 
 namespace Mantid
 {
@@ -120,7 +121,7 @@ void Q1D2::exec()
     try {
       det = m_dataWS->getDetector(i);
     } catch (Exception::NotFoundError&) {
-      g_log.warning() << "Spectrum index " << i << " has no detector assigned to it - discarding" << std::endl;
+      g_log.warning() << "Workspace index " << i << " (SpectrumIndex = " << m_dataWS->getSpectrum(i)->getSpectrumNo() << ") has no detector assigned to it - discarding" << std::endl;
       // Catch if no detector. Next line tests whether this happened - test placed
       // outside here because Mac Intel compiler doesn't like 'continue' in a catch
       // in an openmp block.
diff --git a/Code/Mantid/scripts/SANS/ISISCommandInterface.py b/Code/Mantid/scripts/SANS/ISISCommandInterface.py
index d9b341d53ff..ae71d841b2f 100644
--- a/Code/Mantid/scripts/SANS/ISISCommandInterface.py
+++ b/Code/Mantid/scripts/SANS/ISISCommandInterface.py
@@ -396,6 +396,7 @@ def WavRangeReduction(wav_start=None, wav_end=None, full_trans_wav=None, name_su
             ReductionSingleton.replace(ReductionSingleton().settings())
         
         ReductionSingleton().instrument.setDetector('front')
+        SetDetectorFloodFile('') #FIXME: now the FloodFile does not refer to FRONT/HAB detectors. But, in the future, this line must be erased.
         retWSname_front = _WavRangeReduction(name_suffix)
         retWSname = retWSname_front
 
diff --git a/Code/Mantid/MantidQt/CustomInterfaces/src/SANSRunWindow.cpp b/Code/Mantid/MantidQt/CustomInterfaces/src/SANSRunWindow.cpp
index 1159939ffbf..1065f4cb53a 100644
--- a/Code/Mantid/MantidQt/CustomInterfaces/src/SANSRunWindow.cpp
+++ b/Code/Mantid/MantidQt/CustomInterfaces/src/SANSRunWindow.cpp
@@ -828,7 +828,7 @@ bool SANSRunWindow::loadUserFile()
     m_uiForm.gravity_check->setChecked(false);
   }
   
   ////Detector bank: support REAR, FRONT, HAB, BOTH, MERGED options
   QString detName = runReduceScriptFunction(
     "print i.ReductionSingleton().instrument.det_selection").trimmed();
   if (detName == "REAR" || detName == "MAIN"){
@@ -837,7 +837,7 @@ bool SANSRunWindow::loadUserFile()
      m_uiForm.detbank_sel->setCurrentIndex(1);
   }else if (detName == "BOTH"){
      m_uiForm.detbank_sel->setCurrentIndex(2);
-  }else if (detName == "MERGED"){
+  }else if (detName == "MERGED" || detName== "MERGE"){
      m_uiForm.detbank_sel->setCurrentIndex(3);
   }
  
@@ -1960,7 +1960,7 @@ QString SANSRunWindow::readUserFileGUIChanges(const States type)
 
   if ( ( ! floodFile.isEmpty() ) && ( m_uiForm.detbank_sel->currentText() == "HAB" ) )
   {
-    issueWarning("Flood file may not work", "Flood files have not always been compatible with the HAB detector you might want to check '"+floodFile+"'.\nThe reduction will continue");
+    g_log.warning() << "::SANS::Warning: Flood files will be ignored for the HAB/FRONT detector" <<std::endl; 
   }
   // Set the wavelength ranges, equal to those for the sample unless this box is checked
   // Also check if the Trans Fit on/off tick is on or off. If Off then set the trans_opt to off
@@ -2191,6 +2191,8 @@ void SANSRunWindow::handleReduceButtonClick(const QString & typeStr)
 
   //Reset the objects by initialising a new reducer object
   //py_code = "i._refresh_singleton()";
+  if (runMode == SingleMode) // TODO: test if it is really necessary to reload the file settings.
+  {
   py_code = "\ni.ReductionSingleton().set_instrument(isis_instrument."+getInstrumentClass()+")";
   //restore the settings from the user file
   py_code += "\ni.ReductionSingleton().user_file_path='"+
@@ -2200,7 +2202,7 @@ void SANSRunWindow::handleReduceButtonClick(const QString & typeStr)
 
   std::cout << "\n\n" << py_code.toStdString() << "\n\n";
   runReduceScriptFunction(py_code);
-
+  }
   // Mark that a reload is necessary to rerun the same reduction
   forceDataReload();
   //Reenable stuff
@@ -828,7 +828,7 @@ bool SANSRunWindow::loadUserFile()
   }
   
-  ////Detector bank: support REAR, FRONT, HAB, BOTH, MERGED options
+  ////Detector bank: support REAR, FRONT, HAB, BOTH, MERGED, MERGE options
   QString detName = runReduceScriptFunction(
     "print i.ReductionSingleton().instrument.det_selection").trimmed();
-- 
GitLab